/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.repository');

/**
 * Load data from XML to fill in the repository tree
 */
org.ametys.repository.AOXmlLoader = Ext.extend(org.ametys.tree.XmlTreeLoader, {

	processAttributes: function (attr)
	{
		// Node text
		attr.text = attr.name;
		
        attr.loaded = false;
        attr.expanded = false;
		
		// Specific icon
		attr.icon = getPluginResourcesUrl('repository') + '/img/ametys_node_16.png';
	},
	
	

	/**
	 * Override createNode function to always return a AsyncTreeNode
	 */
	createNode: function(node)
	{
        var attr = {
                tagName: node.tagName
            };

        Ext.each(node.attributes, function(a){
            attr[a.nodeName] = a.nodeValue;
        });
        
        if (attr.noChild=="true"){
        	attr.leaf = true;
        }

        this.processAttributes(attr);

		return new Ext.tree.AsyncTreeNode(attr);
	},
	
	
	
	/**
	 * Override parseXml function to find children in the Xml
	 */
	parseXml: function(node)
	{
		var nodes = [];
		
		Ext.each(
			node.childNodes, 
			function(n) 
			{
				if (n.nodeType == this.XML_NODE_ELEMENT && n.tagName == 'node') 
				{
					
					Ext.each(
							n.childNodes, 
							function(nn) 
							{
								if (nn.nodeType == this.XML_NODE_ELEMENT && nn.tagName == 'node') 
								{
									var treeNode = this.createNode(nn);
									if (nn.childNodes.length > 0) 
									{
										var child = this.parseXml(nn);
										if (typeof child == 'string') 
										{
											treeNode.attributes.innerText = child;
										}
										else 
										{
											treeNode.appendChild(child);
										}
									}
									nodes.push(treeNode);
								} 
								else if (nn.nodeType == this.XML_NODE_TEXT) 
								{
									var text = nn.nodeValue.trim();
									if (text.length > 0) 
									{
										return nodes = text;
									}
								}
							}, 
							this);
				}
			}, 
			this);

		return nodes;
		
	}
});